require(raster)
require(rgdal)
require(data.table)
require(reshape2)
library(sp)
library(rworldmap)
library(RColorBrewer)
library( ggplot2 )
theme_set( theme_bw() )
library(dplyr)
library(gridExtra)
library(viridis)

yy <- 2050
scen <- 'RCP8.5' #set to RCP8.5 or RCP4.5
setwd('C:/Users/vruijven/Documents/DARE files/')

#read data
ClimEnergyTotals <- fread( paste0('Data/',scen,'_ClimEnergyTotals_v2_',yy,"_tot.csv"))

#create total energy variables of interest
ClimEnergyTotals[,TotEnChg:=TotEn/TotEnHist,]
ClimEnergyTotals[,TotEnClimChg:=EnClim/TotEn,]

#read SSP data and add adaptation challenge vector
SSPData <- fread('Data/SSP_GDP.csv')
SSPData$income <- ifelse(SSPData$gdppc<6000,'High adaptation challenge',
                         ifelse(SSPData$gdppc<18000,'Moderate adaptation challenge','Low adaptation challenge'))

# set key for SSPdata and merge with climate impact data
setkey(SSPData,gdppc)
ClimEnergyTotals <- merge(ClimEnergyTotals,SSPData,by=c('ISO3','Year','SCENARIO'))

#Read 6 region aggregation file and add REGION vector to climate data
regions <- read.csv( "Data/agg_6R.csv" )
ClimEnergyTotals$REGION <- regions$NEW[match(ClimEnergyTotals$ISO3,regions$OLD)]

# Generate bins for exposed population
EnBins <- seq(0,2.11,0.01) 

#select only cells with energy consumption and generate vector of exposed people
ClimEnergyTotals <- subset(ClimEnergyTotals,TotEn>0)
ClimEnergyTotals$int <- findInterval(ClimEnergyTotals$TotEnClimChg, EnBins)
temp <- setDT(ClimEnergyTotals)[, list(exposed = sum(people)), by = c("REGION","SCENARIO",'income' ,"gcm", "int")]
setkey(temp,'int')

#create cumulative distribution 
temp2 <- temp[, cumexposed := cumsum(exposed), by = c("REGION","SCENARIO",'income' ,"gcm")]
ClimEnergyTotalSSPX <- temp2
ClimEnergyTotalSSPX[,avg_cum:=mean(cumexposed, na.rm=TRUE),by=c('int',"REGION",'SCENARIO','income')]
setkey(ClimEnergyTotalSSPX,int)

# Prepare for plotting
ClimEnergyTotalSSPX$int <- (EnBins[ClimEnergyTotalSSPX$int]-1)*100
ClimEnergyTotalSSPX$SCENARIO <- as.character(ClimEnergyTotalSSPX$SCENARIO)
ClimEnergyTotalSSPX$REGION <- as.character(ClimEnergyTotalSSPX$REGION)
ClimEnergyTotalSSPX$SCENARIO <- factor(ClimEnergyTotalSSPX$SCENARIO)
ClimEnergyTotalSSPX$REGION <- factor(ClimEnergyTotalSSPX$REGION)
ClimEnergyTotalSSPX <-  arrange(ClimEnergyTotalSSPX,as.integer(income))
ClimEnergyTotalSSPX$grp <- paste0(ClimEnergyTotalSSPX$gcm,"_",ClimEnergyTotalSSPX$income)
ClimEnergyTotalSSPX$income <- factor(ClimEnergyTotalSSPX$income, levels=c('Low adaptation challenge','Moderate adaptation challenge','High adaptation challenge'))

# Create graph for Asia
ClimEnergyTotalSSPR <- subset(ClimEnergyTotalSSPX, REGION=='Asia')
pA <- ggplot()
pA <- pA + geom_line(data=ClimEnergyTotalSSPR, aes(x=int, y=cumexposed/1e+6,color=income, group=grp), alpha=0.4)
pA <- pA + geom_line(data=ClimEnergyTotalSSPR, aes(x=int, y=avg_cum/1e+6,color=income), size=2)
pA <- pA + ylab("million people") + xlab("percentage change in total energy use") 
pA <- pA + scale_x_continuous(breaks = c(-100,-50,0,50,100), labels = c("-100","-50","0","50",">100"))
pA <- pA + scale_color_viridis(discrete=TRUE,guide = guide_legend(title = NULL))
pA <- pA + theme_bw(base_size = 25) #+ ylim(0,800) #+ theme(axis.title.x=element_blank(), axis.title.y=element_blank()) group=rev(SCENARIO)) +
pA <- pA + coord_cartesian(xlim=c(-60,110),expand=FALSE) #ylim=c(0,7500)
pA <- pA + facet_grid(~SCENARIO) + theme(legend.position='bottom') #+ guides(fill=guide_legend(reverse=TRUE))
pA <- pA + labs(title = "Asia")

# Create graph for South America
ClimEnergyTotalSSPR <- subset(ClimEnergyTotalSSPX, REGION=='South America')
pS <- ggplot()
pS <- pS + geom_line(data=ClimEnergyTotalSSPR, aes(x=int, y=cumexposed/1e+6,color=income, group=grp), alpha=0.4)
pS <- pS + geom_line(data=ClimEnergyTotalSSPR, aes(x=int, y=avg_cum/1e+6,color=income), size=2)
pS <- pS + ylab("million people") + xlab("percentage change in total energy use") 
pS <- pS + scale_x_continuous(breaks = c(-100,-50,0,50,100), labels = c("-100","-50","0","50",">100"))
pS <- pS + scale_color_viridis(discrete=TRUE,guide = guide_legend(title = NULL))
pS <- pS + theme_bw(base_size = 25) #+ ylim(0,800) #+ theme(axis.title.x=element_blank(), axis.title.y=element_blank()) group=rev(SCENARIO)) +
pS <- pS + coord_cartesian(xlim=c(-60,110),expand=FALSE) #ylim=c(0,7500)
pS <- pS + facet_grid(~SCENARIO) + theme(legend.position='bottom') #+ guides(fill=guide_legend(reverse=TRUE))
pS <- pS + labs(title = "South America")

# Create graph for Middle East and Africa
ClimEnergyTotalSSPR <- subset(ClimEnergyTotalSSPX, REGION=='Middle East & Africa')
pM <- ggplot()
pM <- pM + geom_line(data=ClimEnergyTotalSSPR, aes(x=int, y=cumexposed/1e+6,color=income, group=grp), alpha=0.4)
pM <- pM + geom_line(data=ClimEnergyTotalSSPR, aes(x=int, y=avg_cum/1e+6,color=income), size=2)
pM <- pM + ylab("million people") + xlab("percentage change in total energy use") 
pM <- pM + scale_x_continuous(breaks = c(-100,-50,0,50,100), labels = c("-100","-50","0","50",">100"))
pM <- pM + scale_color_viridis(discrete=TRUE,guide = guide_legend(title = NULL))
pM <- pM + theme_bw(base_size = 25) #+ ylim(0,800) #+ theme(axis.title.x=element_blank(), axis.title.y=element_blank()) group=rev(SCENARIO)) +
pM <- pM + coord_cartesian(xlim=c(-60,110),expand=FALSE) #ylim=c(0,7500)
pM <- pM + facet_grid(~SCENARIO) + theme(legend.position='bottom') #+ guides(fill=guide_legend(reverse=TRUE))
pM <- pM + labs(title = "Middle East & Africa")

# Create data for World
ClimEnergyTotalSSPW <- temp[, cumexposed := cumsum(exposed), by = c("SCENARIO",'income' ,"gcm")]
ClimEnergyTotalSSPW[,avg_cum:=mean(cumexposed, na.rm=TRUE),by=c('int','SCENARIO','income')]
setkey(ClimEnergyTotalSSPW,int)
ClimEnergyTotalSSPW$int <- (EnBins[ClimEnergyTotalSSPW$int]-1)*100
ClimEnergyTotalSSPW$SCENARIO <- as.character(ClimEnergyTotalSSPW$SCENARIO)
ClimEnergyTotalSSPW$REGION <- as.character(ClimEnergyTotalSSPW$REGION)
ClimEnergyTotalSSPW$SCENARIO <- factor(ClimEnergyTotalSSPW$SCENARIO)
ClimEnergyTotalSSPW$REGION <- factor(ClimEnergyTotalSSPW$REGION)
ClimEnergyTotalSSPW$grp <- paste0(ClimEnergyTotalSSPW$gcm,"_",ClimEnergyTotalSSPW$income)
ClimEnergyTotalSSPW$income <- factor(ClimEnergyTotalSSPW$income, levels=c('Low adaptation challenge','Moderate adaptation challenge','High adaptation challenge'))

# Create graph for World
pW <- ggplot()
pW <- pW + geom_line(data=ClimEnergyTotalSSPW, aes(x=int, y=cumexposed/1e+6,color=income, group=grp), alpha=0.4)
pW <- pW + geom_line(data=ClimEnergyTotalSSPW, aes(x=int, y=avg_cum/1e+6,color=income), size=2)
pW <- pW + ylab("million people") + xlab("percentage change in total energy use") 
pW <- pW + scale_x_continuous(breaks = c(-100,-50,0,50,100), labels = c("-100","-50","0","50",">100"))
pW <- pW + scale_color_viridis(discrete=TRUE,guide = guide_legend(title = NULL))
pW <- pW + theme_bw(base_size = 25) 
pW <- pW + coord_cartesian(ylim=c(0,7500), xlim=c(-60,110),expand=FALSE)
pW <- pW + facet_grid(~SCENARIO) + theme(legend.position='bottom') #+ guides(fill=guide_legend(reverse=TRUE))

# remove legends from individual plots
pA <- pA + theme(legend.position="none")
pS <- pS + theme(legend.position="none")
pW <- pW + theme(legend.position="none")

# add titles to plots
pM <- pM + labs(title = "d: Middle East & Africa")
pA <- pA + labs(title = "b: Asia")
pS <- pS + labs(title = "c: South America")
pW <- pW + labs(title = "a: World")
pW <- pW + theme(strip.background = element_blank(),axis.title.x=element_blank())

# remove axis titles, etc. 
pA <- pA + theme(strip.background = element_blank(), strip.text = element_blank(),axis.title.x=element_blank())
pS <- pS + theme(strip.background = element_blank(), strip.text = element_blank(),axis.title.x=element_blank())
pM <- pM + theme(strip.background = element_blank(), strip.text = element_blank()) 

# arrange new figure
g2 <- arrangeGrob(pW, pA, pS, pM, 
                  ncol=1, nrow =4,
                  heights=c(5.5,5,5,6))

# save figure as png and pdf
ggsave(paste0('Figures/Figure5/',scen,"_ClimEnergy_people_income_regions.png"), g2, width = 18, height = 20)
ggsave(paste0('Figures/Figure5/',scen,"_ClimEnergy_people_income_regions.pdf"), g2, width = 18, height = 20)
